pitchtools.NumberedObject
=========================

.. inheritance-diagram:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
